import * as vue_types_vue from 'vue/types/vue';
import * as vue_types_v3_component_options from 'vue/types/v3-component-options';
import Vue, { VNode } from 'vue';
import { DirectiveBinding } from 'vue/types/options';

type Input = number | string;
interface Options$1 {
    prefix: string;
    suffix: string;
    separator: string;
    decimal: string;
    precision: number;
    minimumFractionDigits: number;
    prefill: boolean;
    reverseFill: boolean;
    min: number;
    max: number;
    nullValue: string;
}
declare class CustomInputEvent<T = any> extends CustomEvent<T> {
    target: CustomInputElement;
}
interface CustomInputElement extends HTMLInputElement {
    options: Options$1;
    masked?: Input;
    unmaskedValue?: Input;
    oldValue?: Input;
    cleanup: () => void;
}

declare const _default$3: vue_types_vue.ExtendedVue<Vue<Record<string, any>, Record<string, any>, never, never, (event: string, ...args: any[]) => Vue<Record<string, any>, Record<string, any>, never, never, any>>, {
    maskedValue: string | number;
    unmaskedValue: Input | undefined;
}, {
    input(event: CustomInputEvent): void;
    change(): void;
}, {
    emittedValue: Input | undefined;
    config: {
        nullValue: any;
        masked: boolean;
        reverseFill: any;
        prefill: any;
        precision: any;
        minimumFractionDigits: any;
        decimal: any;
        min: any;
        max: any;
        separator: any;
        prefix: any;
        suffix: any;
    };
}, {
    value: string | number;
    nullValue: any;
    masked: boolean;
    reverseFill: any;
    prefill: any;
    precision: any;
    minimumFractionDigits: any;
    decimal: any;
    min: any;
    max: any;
    separator: any;
    prefix: any;
    suffix: any;
}, {}, vue_types_v3_component_options.ComponentOptionsMixin, vue_types_v3_component_options.ComponentOptionsMixin>;

declare const _default$2: {
    bind: (el: CustomInputElement, { value, modifiers }: DirectiveBinding, vnode: VNode) => void;
    inserted: (el: CustomInputElement) => void;
    update: (el: CustomInputElement, { value, oldValue, modifiers }: DirectiveBinding, vnode: VNode) => void;
    unbind: (el: CustomInputElement) => void;
};

interface Options {
    prefix?: string;
    suffix?: string;
    separator?: string;
    decimal?: string;
    precision?: number;
    minimumFractionDigits?: number;
    prefill?: boolean;
    reverseFill?: boolean;
    min?: number;
    max?: number;
    nullValue?: string;
}
declare const _default$1: {
    prefix: string;
    suffix: string;
    separator: string;
    decimal: string;
    precision: number;
    minimumFractionDigits: null;
    prefill: boolean;
    reverseFill: boolean;
    min: null;
    max: null;
    nullValue: string;
};

interface Config {
    prefix: string;
    suffix: string;
    separator: string;
    decimal: string;
    precision: number;
    minimumFractionDigits: number;
    prefill: boolean;
    reverseFill: boolean;
    min: number;
    max: number;
    nullValue: string;
}
/**
 * Number format class
 * @param {Options} config
 */
declare class NumberFormat {
    options: Config;
    input: Input;
    number: Input;
    isClean: boolean;
    preSurRegExp: RegExp;
    numberRegExp: RegExp;
    cleanRegExp: RegExp;
    negativeRegExp: RegExp;
    constructor(config?: Options);
    isNull(): boolean;
    clean(clean?: boolean): this;
    sign(): "" | "-";
    toNumber(str: Input): number;
    numberOnly(str: Input, regExp: RegExp): string;
    isNegative(): boolean;
    numbers(): string;
    realNumber(): number;
    parts(num: Input, separator?: string): Input[];
    addSeparator(): string;
    /**
     * Format the input with default config if there is no constructor config
     * @param {Input} input
     * @return {String}
     */
    format(input: Input): string;
    /**
     * Unformat the input with default config if there is no constructor config
     * @param {Input} input
     * @return {String}
     */
    unformat(input: Input): string;
}

declare const _default: {
    install(Vue: any, config?: Options): void;
};

export { NumberFormat, _default$3 as component, _default as default, _default$2 as directive, _default$1 as options };
